@@ -1,37 +1,30 @@
 //
-// "$Id: list_visuals.cxx,v 1.5.2.2 2000/06/05 21:21:22 mike Exp $"
+// "$Id$"
 //
 // Visual list utility for the Fast Light Tool Kit (FLTK).
 //
 // List all the visuals on the screen, and dumps anything interesting
 // about them to stdout.
 //
-// Does not use fltk.
+// Does not use FLTK.
 //
 // This file may be #included in another program to make a function to
 // call to list the visuals.  Fl.H must be included first to indicate this.
 //
-// Copyright 1998-2000 by Bill Spitzak and others.
+// Copyright 1998-2016 by Bill Spitzak and others.
 //
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
-// License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// This library is free software. Distribution and use rights are outlined in
+// the file "COPYING" which should have been included with this file.  If this
+// file is missing or damaged, see the license at:
 //
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Library General Public License for more details.
+//     http://www.fltk.org/COPYING.php
 //
-// You should have received a copy of the GNU Library General Public
-// License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
-// USA.
+// Please report all bugs and problems on the following page:
 //
-// Please report all bugs and problems to "fltk-bugs@fltk.org".
+//     http://www.fltk.org/str.php
 //
 
-#ifdef WIN32
+#if defined(WIN32) || defined(__APPLE__)
 #include <FL/Fl.H>
 #include <FL/fl_message.H>
 
@@ -44,6 +37,8 @@ int main(int, char**) {
 
 #include <config.h>
 
+#define HAVE_MULTIBUF 0
+
 #ifndef Fl_H
 
 #include <X11/Xlib.h>
@@ -220,6 +215,7 @@ void list_visuals() {
 
     putchar('\n');
   }
+  if ( overlayInfo ) { XFree(overlayInfo); overlayInfo = 0; }
 }
 
 #endif
@@ -235,5 +231,5 @@ int main(int argc, char **argv) {
 #endif
 
 //
-// End of "$Id: list_visuals.cxx,v 1.5.2.2 2000/06/05 21:21:22 mike Exp $".
+// End of "$Id$".
 //
